@@ -35,6 +35,8 @@
 #include "panel-applet-atk-object-factory.h"
 #include "gail-gnome-debug.h"
 
+G_MODULE_EXPORT int gtk_module_init (gint *argc, char** argv[]);
+
 /* For automatic libgnome init */
 extern void gnome_accessibility_module_init     (void);
 extern void gnome_accessibility_module_shutdown (void);
@@ -121,7 +123,7 @@ gail_accessibility_init (void)
   gail_bonobo_ui_register_atk_factories (); 
 }
 
-int
+G_MODULE_EXPORT int
 gtk_module_init(gint *argc, char** argv[])
 {
   dprintf ("BonoboUI Accessibility Module loaded\n");
